[meego-commits] 6356: Changes to Trunk:Netbook/meego-panel-myzone

Rob Bradford rob at linux.intel.com
Fri Aug 6 16:56:53 UTC 2010


Hi,
I have made the following changes to meego-panel-myzone in project Trunk:Netbook. Please review and accept ASAP.

Thank You,
Rob Bradford

[This message was auto-generated]

---

Request #6356:

  submit:   devel:ux:netbook/meego-panel-myzone(r7) -> Trunk:Netbook/meego-panel-myzone


Message:
    None

State:   new          2010-08-06T04:48:54 rbradford
Comment: None



changes files:
--------------
--- meego-panel-myzone.changes
+++ meego-panel-myzone.changes
@@ -0,0 +1,3 @@
+* Thu Aug 05 2010 Rob Bradford <rob at linux.intel.com> - 0.2.4
+- Update to new libsocialweb APIs
+

old:
----
  meego-panel-myzone-0.2.3.tar.gz

new:
----
  meego-panel-myzone-0.2.4.tar.gz

spec files:
-----------
--- meego-panel-myzone.spec
+++ meego-panel-myzone.spec
@@ -7,7 +7,7 @@
 
 Name:       meego-panel-myzone
 Summary:    Myzone panel
-Version:    0.2.3
+Version:    0.2.4
 Release:    1
 Group:      System Environment/Desktop
 License:    LGPL 2.1

other changes:
--------------

++++++ meego-panel-myzone-0.2.3.tar.gz -> meego-panel-myzone-0.2.4.tar.gz
--- capplet/myzone-cc-panel.c
+++ capplet/myzone-cc-panel.c
@@ -224,6 +224,9 @@
   bridge = gconf_bridge_get ();
   client = gconf_bridge_get_client (bridge);
 
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
   builder = gtk_builder_new ();
   gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
   gtk_builder_add_from_file (builder,
--- configure
+++ configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for meego-panel-myzone 0.2.3.
+# Generated by GNU Autoconf 2.65 for meego-panel-myzone 0.2.4.
 #
 #
 # Copyright (C) 1992, 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2001,
@@ -698,8 +698,8 @@
 # Identity of this package.
 PACKAGE_NAME='meego-panel-myzone'
 PACKAGE_TARNAME='meego-panel-myzone'
-PACKAGE_VERSION='0.2.3'
-PACKAGE_STRING='meego-panel-myzone 0.2.3'
+PACKAGE_VERSION='0.2.4'
+PACKAGE_STRING='meego-panel-myzone 0.2.4'
 PACKAGE_BUGREPORT=''
 PACKAGE_URL=''
 
@@ -1497,7 +1497,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures meego-panel-myzone 0.2.3 to adapt to many kinds of systems.
+\`configure' configures meego-panel-myzone 0.2.4 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1568,7 +1568,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of meego-panel-myzone 0.2.3:";;
+     short | recursive ) echo "Configuration of meego-panel-myzone 0.2.4:";;
    esac
   cat <<\_ACEOF
 
@@ -1697,7 +1697,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-meego-panel-myzone configure 0.2.3
+meego-panel-myzone configure 0.2.4
 generated by GNU Autoconf 2.65
 
 Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2062,7 +2062,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by meego-panel-myzone $as_me 0.2.3, which was
+It was created by meego-panel-myzone $as_me 0.2.4, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   $ $0 $@
@@ -2870,7 +2870,7 @@
 
 # Define the identity of the package.
  PACKAGE=meego-panel-myzone
- VERSION=0.2.3
+ VERSION=0.2.4
 
 
 cat >>confdefs.h <<_ACEOF
@@ -14389,7 +14389,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by meego-panel-myzone $as_me 0.2.3, which was
+This file was extended by meego-panel-myzone $as_me 0.2.4, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -14455,7 +14455,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-meego-panel-myzone config.status 0.2.3
+meego-panel-myzone config.status 0.2.4
 configured by $0, generated by GNU Autoconf 2.65,
   with options \\"\$ac_cs_config\\"
 
--- configure.ac
+++ configure.ac
@@ -1,5 +1,5 @@
 AC_PREREQ(2.53)
-AC_INIT(meego-panel-myzone, 0.2.3)
+AC_INIT(meego-panel-myzone, 0.2.4)
 AM_INIT_AUTOMAKE(AC_PACKAGE_NAME, AC_PACKAGE_VERSION)
 AC_CONFIG_MACRO_DIR([m4])
 AM_CONFIG_HEADER(config.h)
--- po/ca.po
+++ po/ca.po
@@ -2,12 +2,12 @@
 # Copyright (C) 2009 Free Software Foundation, Inc.
 # This file is distributed under the same license as the myzone package.
 # Gil Forcada <gilforcada at guifi.net>, 2009.
-#
+# 
 msgid ""
 msgstr ""
 "Project-Id-Version: myzone 2.x\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2009-08-15 09:26+0000\n"
+"POT-Creation-Date: 2010-07-20 17:55+0000\n"
 "PO-Revision-Date: 2009-12-31 19:21+0100\n"
 "Last-Translator: Gil Forcada <gilforcada at guifi.net>\n"
 "Language-Team: Catalan <tradgnome at softcatala.org>\n"
@@ -15,57 +15,153 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: ../penge/penge-calendar-pane.c:476
-msgid "<b>Appointments</b>"
-msgstr "<b>Cites</b>"
+#: ../data/meego-panel-myzone.desktop.in.in.h:1
+msgid "Myzone panel"
+msgstr "Tauler Myzone"
+
+#: ../data/myzone.desktop.in.in.h:1
+msgid "Change the Myzone background and content"
+msgstr "Canvia el fons i contingut de Myzone"
+
+#: ../data/myzone.desktop.in.in.h:2 ../capplet/myzone-cc-panel.c:169
+msgid "Myzone"
+msgstr "Myzone"
 
-#: ../penge/penge-events-pane.c:59
+#: ../data/capplet.ui.h:1
+msgid "<b>Change what is shown in your Myzone</b>"
+msgstr ""
+
+#: ../data/capplet.ui.h:2
+msgid "<b>Myzone Wallpaper</b>"
+msgstr "<b>Fons d'escriptori de Myzone</b>"
+
+#: ../data/capplet.ui.h:3
+msgid "Calendar and tasks:"
+msgstr "Calendari i tasques:"
+
+#: ../data/capplet.ui.h:4
+msgid "Change My Web Accounts"
+msgstr ""
+
+#: ../data/capplet.ui.h:5
+msgid "Choose your wallpaper"
+msgstr "Trieu el fons d'escriptori"
+
+#: ../data/capplet.ui.h:6
+msgid "Clear recent documents"
+msgstr "Neteja els documents recents"
+
+#: ../data/capplet.ui.h:7
+msgid "Email alerts:"
+msgstr "Avisos de correu electrònic:"
+
+#: ../data/capplet.ui.h:8
+msgid "Reset to default"
+msgstr "Reinicia als valors per defecte"
+
+#: ../capplet/gconf-bridge.c:1232
+#, c-format
+msgid "GConf error: %s"
+msgstr "Error GConf: %s"
+
+#: ../capplet/gconf-bridge.c:1237
+msgid "All further errors shown only on terminal."
+msgstr "Tots els errors següents es mostraran només al terminal."
+
+#: ../capplet/myzone-cc-panel.c:47
+msgid "Show as much web service content as possible"
+msgstr "Mostra tants serveis web com sigui possible"
+
+#: ../capplet/myzone-cc-panel.c:49
+msgid "Show mostly web service content"
+msgstr "Mostra'n més contingut de serveis web"
+
+#: ../capplet/myzone-cc-panel.c:51
+msgid "Show half and half"
+msgstr "Mostra meitat i meitat"
+
+#: ../capplet/myzone-cc-panel.c:53
+msgid "Show mostly recent files"
+msgstr "Mostra'n més fitxers recents"
+
+#: ../capplet/myzone-cc-panel.c:55
+msgid "Show as many recent files as possible"
+msgstr "Mostra'n tants fitxers recents com sigui possible"
+
+#: ../capplet/myzone-cc-panel.c:77
+msgid "Do you want to clear your recent documents? This will remove the local content from your myzone"
+msgstr "Voleu netejar els documents recents? Això eliminarà el contingut local del vostre myzone"
+
+#: ../penge/penge-calendar-pane.c:484
+msgid "Appointments"
+msgstr "Cites"
+
+#: ../penge/penge-calendar-pane.c:496 ../penge/penge-calendar-pane.c:539
+msgid "Open"
+msgstr "Obre"
+
+#: ../penge/penge-calendar-pane.c:527
+msgid "Tasks"
+msgstr "Tasques"
+
+#: ../penge/penge-events-pane.c:71
 msgid "Create an appointment"
 msgstr "Crea una cita"
 
-#: ../penge/penge-events-pane.c:60 ../penge/penge-tasks-pane.c:52
+#: ../penge/penge-events-pane.c:72 ../penge/penge-tasks-pane.c:53
 msgid "Add"
 msgstr "Afegeix"
 
-#: ../penge/penge-events-pane.c:268
+#: ../penge/penge-events-pane.c:402
 msgid "No calendar entries this week"
 msgstr "No hi ha entrades en el calendari per aquesta setmana"
 
-#: ../penge/penge-people-placeholder-tile.c:112
-msgid ""
-"Things that your friends do online will appear here. Activate your accounts "
-"now!"
-msgstr ""
-"Aquí es mostrarà el que fan en línia els teus amics. Activeu els vostres "
-"comptes"
-
-#: ../penge/penge-recent-file-tile.c:224
+#: ../penge/penge-recent-file-tile.c:217
 msgid "Web page"
 msgstr "Pàgina web"
 
-#: ../penge/penge-tasks-pane.c:51
+#: ../penge/penge-tasks-pane.c:52
 msgid "Create a new task"
 msgstr "Crea una tasca nova"
 
-#: ../penge/penge-tasks-pane.c:433
+#: ../penge/penge-tasks-pane.c:430
 msgid "Nothing to do today"
 msgstr "No hi ha res per avui"
 
-#: ../penge/penge-task-tile.c:325
+#: ../penge/penge-task-tile.c:319
 #, c-format
 msgid "Due %x"
 msgstr "Venç al %x"
 
-#: ../penge/penge-welcome-tile.c:88
-msgid "<b>Welcome to Meego 2.1 for Netbooks</b>"
-msgstr "<b>Benvingut al Meego 2.1 per a mini portàtils</b>"
+#: ../penge/penge-welcome-tile.c:28
+msgid "When you’ve set up your web accounts and used some files they will appear here on myzone for easy access whenever you want. "
+msgstr "Quan hàgiu configurat els comptes web i utilitzat alguns fitxers, apareixeran ací al myzone per a un accés més fàcil sempre que vulgueu."
+
+#: ../penge/penge-welcome-tile.c:34
+msgid "Play intro video"
+msgstr "Reprodueix el vídeo d'introducció"
+
+#: ../penge/penge-welcome-tile.c:87
+msgid "Welcome to MeeGo"
+msgstr "Benvingut al Meego"
+
+#: ../penge/penge-email-pane.c:192
+msgid "No unread messages"
+msgstr "No hi ha cap missatge sense llegir"
+
+#: ../penge/penge-email-pane.c:194
+msgid "Unread message"
+msgstr "Missatge sense llegir"
+
+#: ../penge/penge-email-pane.c:196
+msgid "Unread messages"
+msgstr "Missatges sense llegir"
 
-#: ../penge/penge-welcome-tile.c:108
-msgid ""
-"As Meego is a bit different to other computers, we've put together a couple "
-"of bits and pieces to help you find your way around. We hope you enjoy it, "
-"The Meego Team."
-msgstr ""
-"Així com el Meego és diferent d'altres ordinadors, s'han canviat algunes "
-"parts aquí i allà perquè us sigui més còmode. Esperem que us agradi, "
-"equip del Meego."
+#~ msgid "Things that your friends do online will appear here. Activate your accounts now!"
+#~ msgstr "Aquí es mostrarà el que fan en línia els teus amics. Activeu els vostres comptes"
+
+#~ msgid "<b>Welcome to Meego 2.1 for Netbooks</b>"
+#~ msgstr "<b>Benvingut al Meego 2.1 per a mini portàtils</b>"
+
+#~ msgid "As Meego is a bit different to other computers, we've put together a couple of bits and pieces to help you find your way around. We hope you enjoy it, The Meego Team."
+#~ msgstr "Així com el Meego és diferent d'altres ordinadors, s'han canviat algunes parts aquí i allà perquè us sigui més còmode. Esperem que us agradi, equip del Meego."
--- po/en_GB.po
+++ po/en_GB.po
@@ -7,8 +7,8 @@
 msgstr ""
 "Project-Id-Version: Meego myzone panel\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-04-28 09:36+0000\n"
-"PO-Revision-Date: 2010-04-28 08:36-0800\n"
+"POT-Creation-Date: 2010-07-20 17:55+0000\n"
+"PO-Revision-Date: 2010-07-20 10:56-0800\n"
 "Last-Translator: Margie Foster <margie at linux.intel.com>\n"
 "Language-Team: British English <margie at linux.intel.com>\n"
 "MIME-Version: 1.0\n"
@@ -94,8 +94,8 @@
 msgstr "Show as many recent files as possible"
 
 #: ../capplet/myzone-cc-panel.c:77
-msgid "Do you want to clear your recent documents? This will remove the local content from the Myzone"
-msgstr "Do you want to clear your recent documents? This will remove the local content from Myzone."
+msgid "Do you want to clear your recent documents? This will remove the local content from your myzone"
+msgstr "Do you want to clear your recent documents? This will remove the local content from your myzone"
 
 #: ../penge/penge-calendar-pane.c:484
 msgid "Appointments"
@@ -140,22 +140,18 @@
 msgid "Due %x"
 msgstr "Due %x"
 
-#: ../penge/penge-welcome-tile.c:33
+#: ../penge/penge-welcome-tile.c:28
+msgid "When you’ve set up your web accounts and used some files they will appear here on myzone for easy access whenever you want. "
+msgstr "When you’ve set up your web accounts and used some files they will appear here on myzone for easy access whenever you want. "
+
+#: ../penge/penge-welcome-tile.c:34
 msgid "Play intro video"
 msgstr "Play intro video"
 
-#: ../penge/penge-welcome-tile.c:65
+#: ../penge/penge-welcome-tile.c:87
 msgid "Welcome to MeeGo"
 msgstr "Welcome to MeeGo"
 
-#: ../penge/penge-welcome-tile.c:84
-msgid "This is the Myzone, where your recently used files and content from your web feeds will appear."
-msgstr "This is Myzone, where your recently used files and content from your web feeds appear."
-
-#: ../penge/penge-welcome-tile.c:27
-msgid "When you’ve set up your web accounts and used some files they will appear here on the Myzone for easy access whenever you want. "
-msgstr "When you’ve set up your web accounts and opened some files, they appear here on the Myzone for easy access whenever you want. "
-
 #: ../penge/penge-email-pane.c:192
 msgid "No unread messages"
 msgstr "No unread messages"
@@ -169,13 +165,22 @@
 msgstr "Unread messages"
 
 #~ msgid ""
+#~ "This is the Myzone, where your recently used files and content from your "
+#~ "web feeds will appear."
+#~ msgstr ""
+#~ "This is Myzone, where your recently used files and content from your web "
+#~ "feeds appear."
+
+#~ msgid ""
 #~ "Things that your friends do online will appear here. Activate your "
 #~ "accounts now!"
 #~ msgstr ""
 #~ "Things that your friends do online will appear here. Activate your "
 #~ "accounts now!"
+
 #~ msgid "<b>Welcome to Meego 2.1 for Netbooks</b>"
 #~ msgstr "<b>Welcome to Meego 2.1 for Netbooks</b>"
+
 #~ msgid ""
 #~ "As Meego is a bit different to other computers, we've put together a "
 #~ "couple of bits and pieces to help you find your way around. We hope you "
@@ -184,4 +189,3 @@
 #~ "As Meego is a bit different from other computers, we've put together a "
 #~ "couple of bits and pieces to help you find your way around. We hope you "
 #~ "enjoy it. The Meego Team."
-
--- po/pa.po
+++ po/pa.po
@@ -6,8 +6,8 @@
 msgstr ""
 "Project-Id-Version: \n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2010-05-05 09:34+0000\n"
-"PO-Revision-Date: 2010-05-06 07:48+0530\n"
+"POT-Creation-Date: 2010-07-20 17:55+0000\n"
+"PO-Revision-Date: 2010-07-30 08:58+0530\n"
 "Last-Translator: A S Alam <aalam at users.sf.net>\n"
 "Language-Team: Punjabi/Panjabi <punjabi-users at lists.sf.net>\n"
 "MIME-Version: 1.0\n"
@@ -92,9 +92,9 @@
 #: ../capplet/myzone-cc-panel.c:77
 msgid ""
 "Do you want to clear your recent documents? This will remove the local "
-"content from the Myzone"
+"content from your myzone"
 msgstr ""
-"ਕੀ ਤੁਸੀਂ ਆਪਣੇ ਤਾਜ਼ਾ ਡੌਕੂਮੈਂਟ ਸਾਫ਼ ਕਰਨਾ ਚਾਹੁੰਦੇ ਹੋ? ਇਸ ਨਾਲ Myzone ਤੋਂ ਲੋਕਲ ਸਮੱਗਰੀ ਹਟਾਈ ਜਾਵੇਗੀ"
+"ਕੀ ਤੁਸੀਂ ਆਪਣੇ ਤਾਜ਼ਾ ਡੌਕੂਮੈਂਟ ਸਾਫ਼ ਕਰਨਾ ਚਾਹੁੰਦੇ ਹੋ? ਇਸ ਨਾਲ myzone ਤੋਂ ਲੋਕਲ ਸਮੱਗਰੀ ਹਟਾਈ ਜਾਵੇਗੀ"
 
 #: ../penge/penge-calendar-pane.c:484
 msgid "Appointments"
@@ -137,29 +137,22 @@
 msgid "Due %x"
 msgstr "%x ਨੂੰ ਚਾਹੀਦਾ"
 
-#: ../penge/penge-welcome-tile.c:33
+#: ../penge/penge-welcome-tile.c:28
+msgid ""
+"When you’ve set up your web accounts and used some files they will appear "
+"here on myzone for easy access whenever you want. "
+msgstr ""
+"ਜਦੋਂ ਤੁਸੀਂ ਆਪਣੇ ਵੈੱਬ ਅਕਾਊਂਟ ਸੈਟਅੱਪ ਕਰ ਲਏ ਅਤੇ ਵਰਤੇ ਤਾਂ ਕੁਝ ਫਾਇਲਾਂ myzone ਵਿੱਚ ਕੁਝ ਫਾਇਲਾਂ ਸੌਖੀ "
+"ਵਰਤੋਂ ਲਈ ਵੇਖਾਈ ਦੇਣਗੀਆਂ, ਜਦੋਂ ਵੀ ਤੁਸੀਂ ਚਾਹੋਗੇ।"
+
+#: ../penge/penge-welcome-tile.c:34
 msgid "Play intro video"
 msgstr "ਜਾਣਕਾਰੀ ਵਿਡੀਓ ਚਲਾਓ"
 
-#: ../penge/penge-welcome-tile.c:65
+#: ../penge/penge-welcome-tile.c:87
 msgid "Welcome to MeeGo"
 msgstr "ਮੀਗੋ ਵਲੋਂ ਜੀ ਆਇਆਂ ਨੂੰ"
 
-#: ../penge/penge-welcome-tile.c:84
-msgid ""
-"This is the Myzone, where your recently used files and content from your web "
-"feeds will appear."
-msgstr ""
-"ਇਹ Myzone ਹੈ, ਜਿੱਥੇ ਤੁਹਾਡੇ ਵਲੋਂ ਤਾਜ਼ਾ ਵਰਤੀਆਂ ਫਾਇਲਾਂ ਅਤੇ ਤੁਹਾਡੀ ਵੈੱਬ ਫੀਡ ਦੀ ਸਮੱਗਰੀ ਵੇਖਾਈ ਦੇਵੇਗੀ।"
-
-#: ../penge/penge-welcome-tile.c:27
-msgid ""
-"When you’ve set up your web accounts and used some files they will appear "
-"here on the Myzone for easy access whenever you want. "
-msgstr ""
-"ਜਦੋਂ ਤੁਸੀਂ ਆਪਣੇ ਵੈੱਬ ਅਕਾਊਂਟ ਸੈਟਅੱਪ ਕਰ ਲਏ ਅਤੇ ਵਰਤੇ ਤਾਂ ਕੁਝ ਫਾਇਲਾਂ Myzone ਵਿੱਚ ਕੁਝ ਫਾਇਲਾਂ ਸੌਖੀ "
-"ਵਰਤੋਂ ਲਈ ਵੇਖਾਈ ਦੇਣਗੀਆਂ, ਜਦੋਂ ਵੀ ਤੁਸੀਂ ਚਾਹੋਗੇ।"
-
 #: ../penge/penge-email-pane.c:192
 msgid "No unread messages"
 msgstr "ਕੋਈ ਨਾ-ਪੜ੍ਹਿਆ ਸੁਨੇਹਾ ਨਹੀਂ"
@@ -173,6 +166,13 @@
 msgstr "ਨਾ-ਪੜ੍ਹੇ ਸੁਨੇਹੇ"
 
 #~ msgid ""
+#~ "This is the Myzone, where your recently used files and content from your "
+#~ "web feeds will appear."
+#~ msgstr ""
+#~ "ਇਹ Myzone ਹੈ, ਜਿੱਥੇ ਤੁਹਾਡੇ ਵਲੋਂ ਤਾਜ਼ਾ ਵਰਤੀਆਂ ਫਾਇਲਾਂ ਅਤੇ ਤੁਹਾਡੀ ਵੈੱਬ ਫੀਡ ਦੀ ਸਮੱਗਰੀ ਵੇਖਾਈ "
+#~ "ਦੇਵੇਗੀ।"
+
+#~ msgid ""
 #~ "Things that your friends do online will appear here. Activate your "
 #~ "accounts now!"
 #~ msgstr "ਤੁਹਾਡੇ ਦੋਸਤ ਚੀਜ਼ਾਂ ਕਰਨਗੇ, ਉਹ ਇੱਥੇ ਵੇਖਾਈਆਂ ਜਾਣਗੀਆਂ। ਆਪਣਾ ਅਕਾਊਂਟ ਹੁਣੇ ਐਕਟੀਵੇਟ ਕਰੋ!"

++++++ meego-panel-myzone.yaml
--- meego-panel-myzone.yaml
+++ meego-panel-myzone.yaml
@@ -1,6 +1,6 @@
 Name: meego-panel-myzone
 Summary: Myzone panel
-Version: 0.2.3
+Version: 0.2.4
 Release: 1
 Group: System Environment/Desktop
 License: LGPL 2.1


More information about the MeeGo-commits mailing list
--- penge/penge-everything-pane.c
+++ penge/penge-everything-pane.c
@@ -48,7 +48,7 @@
 
 struct _PengeEverythingPanePrivate {
   SwClient *client;
-  SwClientView *view;
+  GList *views;
   GtkRecentManager *recent_manager;
   GHashTable *pointer_to_actor;
 
@@ -102,10 +102,10 @@
     priv->uuid_to_sw_items = NULL;
   }
 
-  if (priv->view)
+  while (priv->views)
   {
-    g_object_unref (priv->view);
-    priv->view = NULL;
+    g_object_unref ((GObject *)priv->views->data);
+    priv->views = g_list_delete_link (priv->views, priv->views);
   }
 
   if (priv->client)
@@ -222,12 +222,18 @@
 {
   PengeEverythingPane *pane = (PengeEverythingPane *)userdata;
   PengeEverythingPanePrivate *priv = GET_PRIVATE (pane);
+  SwClientService *service;
   SwItem *item;
 
   g_object_get (tile,
                 "item", &item,
                 NULL);
-  sw_client_hide_item (priv->client, item);
+
+  service = sw_client_get_service (priv->client, item->service);
+
+  sw_client_service_banishable_hide_item (service, item->uuid);
+
+  g_object_unref (service);
 }
 
 static ClutterActor *
@@ -560,9 +566,9 @@
 }
 
 static void
-_view_items_added_cb (SwClientView *view,
-                      GList        *items,
-                      gpointer      userdata)
+_view_items_added_cb (SwClientItemView *view,
+                      GList            *items,
+                      gpointer          userdata)
 {
   PengeEverythingPane *pane = PENGE_EVERYTHING_PANE (userdata);
   PengeEverythingPanePrivate *priv = GET_PRIVATE (pane);
@@ -571,6 +577,7 @@
   for (l = items; l; l = l->next)
   {
     SwItem *item = (SwItem *)l->data;
+    g_debug (G_STRLOC ": Item added: %s", item->uuid);
     g_hash_table_insert (priv->uuid_to_sw_items,
                          g_strdup (item->uuid),
                          sw_item_ref (item));
@@ -580,9 +587,9 @@
 }
 
 static void
-_view_items_removed_cb (SwClientView *view,
-                        GList        *items,
-                        gpointer      userdata)
+_view_items_removed_cb (SwClientItemView *view,
+                        GList            *items,
+                        gpointer          userdata)
 {
   PengeEverythingPane *pane = PENGE_EVERYTHING_PANE (userdata);
   PengeEverythingPanePrivate *priv = GET_PRIVATE (pane);
@@ -592,6 +599,7 @@
   for (l = items; l; l = l->next)
   {
     SwItem *item = (SwItem *)l->data;
+    g_debug (G_STRLOC ": Item removed: %s", item->uuid);
     g_hash_table_remove (priv->uuid_to_sw_items,
                          item->uuid);
   }
@@ -600,9 +608,9 @@
 }
 
 static void
-_view_items_changed_cb (SwClientView *view,
-                        GList        *items,
-                        gpointer      userdata)
+_view_items_changed_cb (SwClientItemView *view,
+                        GList            *items,
+                        gpointer          userdata)
 {
   PengeEverythingPane *pane = PENGE_EVERYTHING_PANE (userdata);
   PengeEverythingPanePrivate *priv = GET_PRIVATE (pane);
@@ -614,7 +622,9 @@
     SwItem *item = (SwItem *)l->data;
     ClutterActor *actor;
 
-    /* Important to note that SwClientView reuses the SwItem so the
+    g_debug (G_STRLOC ": Item changed: %s", item->uuid);
+
+    /* Important to note that SwClientItemView reuses the SwItem so the
      * pointer is a valid piece of lookup
      */
     actor = g_hash_table_lookup (priv->pointer_to_actor,
@@ -636,9 +646,9 @@
 }
 
 static void
-_client_open_view_cb (SwClient     *client,
-                      SwClientView *view,
-                      gpointer      userdata)
+_client_open_view_cb (SwClientService  *service,
+                      SwClientItemView *view,
+                      gpointer          userdata)
 {
   PengeEverythingPane *pane = PENGE_EVERYTHING_PANE (userdata);
   PengeEverythingPanePrivate *priv = GET_PRIVATE (pane);
@@ -646,7 +656,7 @@
   if (!view)
     return;
 
-  priv->view = view;
+  priv->views = g_list_append (priv->views, view);
 
   g_signal_connect (view,
                     "items-added",
@@ -661,21 +671,31 @@
                     (GCallback)_view_items_changed_cb,
                     userdata);
 
-  sw_client_view_start (view);
+  sw_client_item_view_start (view);
 }
 
 static void
 _client_get_services_cb (SwClient    *client,
-                         const GList *services,
+                         GList *services,
                          gpointer     userdata)
 {
   PengeEverythingPane *pane = PENGE_EVERYTHING_PANE (userdata);
+  GList *l;
 
-  sw_client_open_view (client,
-                       (GList *)services,
-                       50,
-                       _client_open_view_cb,
-                       pane);
+  for (l = services; l; l = l->next)
+  {
+    SwClientService *service;
+
+    service = sw_client_get_service (client, (const gchar *)l->data);
+
+    sw_client_service_query_open_view (service,
+                                       "feed",
+                                       NULL,
+                                       _client_open_view_cb,
+                                       pane);
+
+    g_object_unref (service);
+  }
 }
 
 static void
@@ -740,7 +760,9 @@
                                                   (GDestroyNotify)sw_item_unref);
 
   priv->client = sw_client_new ();
-  sw_client_get_services (priv->client, _client_get_services_cb, self);
+  sw_client_get_services (priv->client,
+                          (SwClientGetServicesCallback)_client_get_services_cb,
+                          self);
 
   priv->recent_manager = gtk_recent_manager_new ();
 